using System;
using System.IO;

class FileSystemWatcherDemo
{
	static void Main()
	{
		string currentDir = Environment.CurrentDirectory;
		
		FileSystemWatcher w = 
			new FileSystemWatcher(currentDir);
		w.Filter = "*.*";
		w.NotifyFilter = NotifyFilters.FileName |
			NotifyFilters.DirectoryName |
			NotifyFilters.LastWrite;
		w.Created += new FileSystemEventHandler(OnCreated);
		w.Changed += new FileSystemEventHandler(OnChanged);
		w.Renamed += new RenamedEventHandler(OnRenamed);
		w.EnableRaisingEvents = true;

		Console.WriteLine(
			"{0} is being watched now...", currentDir);
		Console.WriteLine("Press [Enter] to exit.");

		Console.ReadLine();
	}

	private static void OnCreated(object aSource,
		FileSystemEventArgs aArgs)
	{
		Console.WriteLine("File: {0} created - {1}",
			aArgs.Name, aArgs.ChangeType);
	}

	private static void OnChanged(object aSource,
		FileSystemEventArgs aArgs)
	{
		Console.WriteLine("File: {0} changed - {1}",
			aArgs.Name, aArgs.ChangeType);
	}

	private static void OnRenamed(object aSource,
		RenamedEventArgs aArgs)
	{
		Console.WriteLine("File: {0} renamed to {1}",
			aArgs.OldName, aArgs.Name);
	}
}
